clear all

% relative blood volume ranging from 1 to 15
f0=linspace(1,15,100);
f0=f0./100;


% ratio of f_v and f_a ranging from 2 to 5
fa=zeros([100,6]); % fa = fraction of arterial blood
fa(:,1)=f0/2;
for i=2:6
    fa(:,i)=f0/(i+1);
end

fv=zeros([100,6]); %fv = fraction of venous blood
fv(:,1)=f0/2;
for k=2:6
    fv(:,k)=fa(:,k)*k;
end



TE=56;%ms
TR=2800;%ms

f_7T_base=0.0384*ones(1,100); % measured f-value before muscle activation
f_7T_act =0.0707*ones(1,100); % measured f-value after muscle activation

f_055T_base=0.0708*ones(1,100); % measured f-value before muscle activation
f_055T_act =0.1304*ones(1,100); % measured f-value after muscle activation



% T2 times from Table 1
T2a=[207,55];%ms for 0.55T and 7T       55 vs 45
T2v=[148,20];%ms                        20 vs 17
T2m=[44,22];%ms

% T1 times from Table 2
T1a=[1122 2290];%ms
T1v=[1122 2090];%ms
T1m=[701 1864];%ms


% Estimation of relaxation weights 
% Estiamtion for 0.55 T
wa_055T=exp(-TE/T2a(:,1))*(1-exp(-TR/T1a(:,1))); %wa = relaxation weigth arterial blood
wv_055T=exp(-TE/T2v(:,1))*(1-exp(-TR/T1v(:,1))); %wv = relaxation weight vvenous blood 
wm_055T=exp(-TE/T2m(:,1))*(1-exp(-TR/T1m(:,1))); %wm = relaxation weight muscle

% Estimation for 7 T
wa_7T=exp(-TE/T2a(:,2))*(1-exp(-TR/T1a(:,2)));
wv_7T=exp(-TE/T2v(:,2))*(1-exp(-TR/T1v(:,2)));   
wm_7T=exp(-TE/T2m(:,2))*(1-exp(-TR/T1m(:,2)));


% Estimation of relaxation weighted perfusion fraction 
f_055T=zeros([100,6]); % f_055T = perfusion fraction for B0 = 0.55 T
for l=1:6
    for t=1:100
        f_055T(t,l)=(fa(t,l)*wa_055T+fv(t,l)*wv_055T)/(fa(t,l)*wa_055T+fv(t,l)*wv_055T+(1-fa(t,l)-fv(t,l))*wm_055T);    
    end
end

f_7T=zeros([100,6]);  % f_7T = Perfusion fraction for B0 = 7 T
for l=1:6
    for t=1:100
        f_7T(t,l)=(fa(t,l)*wa_7T+fv(t,l)*wv_7T)/(fa(t,l)*wa_7T+fv(t,l)*wv_7T+(1-fa(t,l)-fv(t,l))*wm_7T);
    end
end


figure (1)
tiledlayout(3,2)

% -------------------------------------------------------------------------
% Plot for 0.55 T 
% -------------------------------------------------------------------------
nexttile
plot(f0*100,f_055T(:,2)*100,'LineWidth', 2)
hold on;
plot(f0*100,f_055T(:,3)*100,'LineWidth', 2)
plot(f0*100,f_055T(:,4)*100,'LineWidth', 2)
plot(f0*100,f_055T(:,5)*100,'LineWidth', 2)
plot(f0*100,f_055T(:,6)*100,'LineWidth', 2)
plot(f0*100,f_055T_base*100, 'r-.','LineWidth', 2)        % plot measured f-values
plot(f0*100,f_055T_act*100, 'r--','LineWidth', 2)
hold off

set(gca,'FontSize',10)

xlim ([1 8])
ylim ([3 15])
xlabel('f_0 [%]')
ylabel('f [%]')
title('0.55 T, relaxation times from Table 1');
 
lgd = legend('2','3','4','5','6','Location','southeast')
title(lgd,'f_v/f_a')

text(1.25,13.7,'activated')
text(1.25,7.9,'baseline')

%%
% -------------------------------------------------------------------------
% Plot for 7 T, fv/fa variation 
% -------------------------------------------------------------------------
nexttile
plot(f0*100,f_7T(:,2)*100,'LineWidth', 2)
hold on
plot(f0*100,f_7T(:,3)*100,'LineWidth', 2)
plot(f0*100,f_7T(:,4)*100,'LineWidth', 2)
plot(f0*100,f_7T(:,5)*100,'LineWidth', 2)
plot(f0*100,f_7T(:,6)*100,'LineWidth', 2)
plot(f0*100,f_7T_base*100, 'r-.','LineWidth', 2)     % plot measured f-values 
plot(f0*100,f_7T_act*100, 'r--','LineWidth', 2)
hold off

set(gca,'FontSize',10)

xlim ([1 8])
ylim ([3 15])
xlabel('f_0 [%]')
ylabel('f [%]')
title('7 T, relaxation times from Table 1');

lgd = legend('2','3','4','5','6','Location','northwest')
title(lgd,'f_v/f_a')






% -------------------------------------------------------------------------
% Plot for 7 T, venous T2 time variation 
% -------------------------------------------------------------------------

f_7T = zeros([100,3]);  % f_7T = Perfusion fraction for B0 = 7 T

i = 4; % index for f_v/f_v

% With venous T2 value from Table 1, for fv/fa=4
wv_7T=exp(-TE/T2v(:,2))*(1-exp(-TR/T1v(:,2)));   
f_7T(:,2)=(fa(:,i)*wa_7T+fv(:,i)*wv_7T)./(fa(:,i)*wa_7T+fv(:,i)*wv_7T+(1-fa(:,i)-fv(:,i))*wm_7T);

% With venous T2 value from Table 1 reduced by 10%, for fv/fa=3
wv_7T=exp(-TE/(T2v(:,2)*0.85))*(1-exp(-TR/T1v(:,2)));   
f_7T(:,1)=(fa(:,i)*wa_7T+fv(:,i)*wv_7T)./(fa(:,i)*wa_7T+fv(:,i)*wv_7T+(1-fa(:,i)-fv(:,i))*wm_7T);

% With venous T2 value from Table 1 increasd by 10%, for fv/fa=3
wv_7T=exp(-TE/(T2v(:,2)*1.15))*(1-exp(-TR/T1v(:,2)));   
f_7T(:,3)=(fa(:,i)*wa_7T+fv(:,i)*wv_7T)./(fa(:,i)*wa_7T+fv(:,i)*wv_7T+(1-fa(:,i)-fv(:,i))*wm_7T);

nexttile
plot(f0*100,f_7T(:,1)*100,'LineWidth', 2)
hold on
plot(f0*100,f_7T(:,2)*100,'LineWidth', 2)
plot(f0*100,f_7T(:,3)*100,'LineWidth', 2)
plot(f0*100,f_7T_base*100, 'r-.','LineWidth', 2)     % plot measured f-values 
plot(f0*100,f_7T_act*100, 'r--','LineWidth', 2)
hold off

set(gca,'FontSize',10)

xlim ([1 8])
ylim ([3 15])
xlabel('f_0 [%]')
ylabel('f [%]')
title('7 T, f_v/f_a=4');

lgd = legend({'reduced by 15 %','from Table 1, = 20 ms','increased by 15 %'},'Location','northwest')
title(lgd,'venous T_2')






% -------------------------------------------------------------------------
% Plot for 7 T, arterial T2 time variation 
% -------------------------------------------------------------------------

f_7T = zeros([100,3]);  % f_7T = Perfusion fraction for B0 = 7 T

i = 4; % index for f_v/f_v

% With arterial T2 value from Table 1, for fv/fa=3
wa_7T=exp(-TE/T2a(:,2))*(1-exp(-TR/T1a(:,2)));
f_7T(:,2)=(fa(:,i)*wa_7T+fv(:,i)*wv_7T)./(fa(:,i)*wa_7T+fv(:,i)*wv_7T+(1-fa(:,i)-fv(:,i))*wm_7T);

% With arterial T2 value from Table 1 reduced by 50%, for fv/fa=3
wa_7T=exp(-TE/(T2a(:,2)*0.5))*(1-exp(-TR/T1a(:,2)));
f_7T(:,1)=(fa(:,i)*wa_7T+fv(:,i)*wv_7T)./(fa(:,i)*wa_7T+fv(:,i)*wv_7T+(1-fa(:,i)-fv(:,i))*wm_7T);

% With arterial T2 value from Table 1 increasd by 50%, for fv/fa=3
wa_7T=exp(-TE/(T2a(:,2)*1.5))*(1-exp(-TR/T1a(:,2)));
f_7T(:,3)=(fa(:,i)*wa_7T+fv(:,i)*wv_7T)./(fa(:,i)*wa_7T+fv(:,i)*wv_7T+(1-fa(:,i)-fv(:,i))*wm_7T);

nexttile
plot(f0*100,f_7T(:,1)*100,'LineWidth', 2)
hold on
plot(f0*100,f_7T(:,2)*100,'LineWidth', 2)
plot(f0*100,f_7T(:,3)*100,'LineWidth', 2)
plot(f0*100,f_7T_base*100, 'r-.','LineWidth', 2)     % plot measured f-values 
plot(f0*100,f_7T_act*100, 'r--','LineWidth', 2)
hold off

set(gca,'FontSize',10)

xlim ([1 8])
ylim ([3 15])
xlabel('f_0 [%]')
ylabel('f [%]')
title('7 T, f_v/f_a=4');

lgd = legend({'reduced by 50 %','from Table 1, = 55 ms','increased by 50 %'},'Location','northwest')
title(lgd,'arterial T_2')







% -------------------------------------------------------------------------
% Plot for 7 T, muscle T2 time variation 
% -------------------------------------------------------------------------

f_7T = zeros([100,3]);  % f_7T = Perfusion fraction for B0 = 7 T

i = 4; % index for f_v/f_v

% With arterial T2 value from Table 1, for fv/fa=3
wm_7T=exp(-TE/T2m(:,2))*(1-exp(-TR/T1m(:,2)));
f_7T(:,2)=(fa(:,i)*wa_7T+fv(:,i)*wv_7T)./(fa(:,i)*wa_7T+fv(:,i)*wv_7T+(1-fa(:,i)-fv(:,i))*wm_7T);

% With arterial T2 value from Table 1 reduced by 10%, for fv/fa=3
wm_7T=exp(-TE/(T2m(:,2)*0.75))*(1-exp(-TR/T1m(:,2)));
f_7T(:,1)=(fa(:,i)*wa_7T+fv(:,i)*wv_7T)./(fa(:,i)*wa_7T+fv(:,i)*wv_7T+(1-fa(:,i)-fv(:,i))*wm_7T);

% With arterial T2 value from Table 1 increasd by 10%, for fv/fa=3
wm_7T=exp(-TE/(T2m(:,2)*1.25))*(1-exp(-TR/T1m(:,2)));
f_7T(:,3)=(fa(:,i)*wa_7T+fv(:,i)*wv_7T)./(fa(:,i)*wa_7T+fv(:,i)*wv_7T+(1-fa(:,i)-fv(:,i))*wm_7T);

nexttile
plot(f0*100,f_7T(:,3)*100,'LineWidth', 2)
hold on
plot(f0*100,f_7T(:,2)*100,'LineWidth', 2)
plot(f0*100,f_7T(:,1)*100,'LineWidth', 2)
plot(f0*100,f_7T_base*100, 'r-.','LineWidth', 2)     % plot measured f-values 
plot(f0*100,f_7T_act*100, 'r--','LineWidth', 2)
hold off

set(gca,'FontSize',10)

xlim ([1 8])
ylim ([3 15])
xlabel('f_0 [%]')
ylabel('f [%]')
title('7 T, f_v/f_a=4');

lgd = legend({'increased by 25 %','22 ms (from Table 1)','decreased by 25 %'},'Location','northwest')
title(lgd,'muscle T_2')







% -------------------------------------------------------------------------
% Plot for 7 T, all T2 times fixed 
% -------------------------------------------------------------------------

f_7T = zeros([100,3]);  % f_7T = Perfusion fraction for B0 = 7 T

i = 4; % index for f_v/f_v

% With arterial T2 value from Table 1, for fv/fa=4
wa_7T=exp(-TE/(T2a(:,2)*0.95))*(1-exp(-TR/T1a(:,2)));
wv_7T=exp(-TE/(T2v(:,2)*0.95))*(1-exp(-TR/T1v(:,2)));   
wm_7T=exp(-TE/(T2m(:,2)*1.05))*(1-exp(-TR/T1m(:,2)));



f_7T(:,1)=(fa(:,i)*wa_7T+fv(:,i)*wv_7T)./(fa(:,i)*wa_7T+fv(:,i)*wv_7T+(1-fa(:,i)-fv(:,i))*wm_7T);



nexttile
plot(f0*100,f_7T(:,1)*100,'LineWidth', 2)
hold on
plot(f0*100,f_7T_base*100, 'r-.','LineWidth', 2)     % plot measured f-values 
plot(f0*100,f_7T_act*100, 'r--','LineWidth', 2)
hold off

set(gca,'FontSize',10)

xlim ([1 8])
ylim ([3 15])
xlabel('f_0 [%]')
ylabel('f [%]')
title('7 T, f_v/f_a=4');

text (1.5,12,{'venous T_2 reduced by 5 %',' arterial T_2 reduced by 5 %','muscle T_2 increased by 5 %'})


